@@ -1,15 +1,17 @@
+
 import pytest
 from .mixins import TestModelClass, TestSerializerClass, TestrepresentationViewSetClass, TestViewSetClass
-from .utils import get_all_subclasses
+from .utils import get_all_subclasses, is_intermediate_table_m2m
 from bridger import serializers
 from bridger import viewsets
 from django.db import models
 from django.urls import get_resolver
 get_resolver().url_patterns
 
-models = filter(lambda x: not x.__module__.startswith(('bridger', 'django', 'rest_framework')), get_all_subclasses(models.Model))
+models = filter(lambda x: not x.__module__.startswith(('bridger', 'django', 'rest_framework', 'dynamic_preferences', 'eventtools')) 
+                and not x._meta.abstract and not is_intermediate_table_m2m(x), get_all_subclasses(models.Model))
 serializers = filter(lambda x: "bridger" not in x.__module__, get_all_subclasses(serializers.ModelSerializer))
-representationmodelviewsets = filter(lambda x: "bridger" not in x.__module__, get_all_subclasses(viewsets.RepresentationModelViewSet))
+representationviewsets = filter(lambda x: "bridger" not in x.__module__, get_all_subclasses(viewsets.RepresentationViewSet))
 modelviewsets = filter(lambda x: "bridger" not in x.__module__, get_all_subclasses(viewsets.ModelViewSet))
 
 @pytest.mark.django_db 
@@ -18,6 +20,7 @@ class TestProject:
     def test_models(self, model):
         # print(mvs.__name__)
         # print(mvs.__module__)
+        # print(model.__dict__)
         my_test = TestModelClass(model)
         my_test.execute_test()
 
@@ -26,9 +29,9 @@ class TestProject:
         my_test = TestSerializerClass(serializer)
         my_test.execute_test()
 
-    @pytest.mark.parametrize("rmvs", representationmodelviewsets)
-    def test_representationmodelviewsets(self, rmvs, admin_client):
-        my_test = TestrepresentationViewSetClass(rmvs)
+    @pytest.mark.parametrize("rvs", representationviewsets)
+    def test_representationviewsets(self, rvs, admin_client):
+        my_test = TestrepresentationViewSetClass(rvs)
         my_test.execute_test(admin_client)
 
     @pytest.mark.parametrize("mvs", modelviewsets)
